@@ -1,16 +1,16 @@
 #' @title Dimensions of an edsurvey.data.frame or an edsurvey.data.frame.list
-#' 
+#'
 #' @description Returns the dimensions of an \code{edsurvey.data.frame} or an
 #'              \code{edsurvey.data.frame.list}.
 #'
 #' @param x an \code{edsurvey.data.frame} or an \code{edsurvey.data.frame.list}
-#' @return For an \code{edsurvey.data.frame}, returns a 
+#' @return For an \code{edsurvey.data.frame}, returns a
 #'         numeric vector of length two, with the first element being the number
 #'         of rows and the second element being the number of columns.
-#'         
-#'         For an \code{edsurvey.data.frame.list}, returns a list of length 
-#'         two, where the first element is named \code{nrow} and is a 
-#'         numeric vector containing the number of rows for each element of the 
+#'
+#'         For an \code{edsurvey.data.frame.list}, returns a list of length
+#'         two, where the first element is named \code{nrow} and is a
+#'         numeric vector containing the number of rows for each element of the
 #'         \code{edsurvey.data.frame.list}. The second element is named
 #'         \code{ncol} and is the number of columns for each element.
 #'         This is done so that the \code{nrow} and \code{ncol} functions
@@ -20,20 +20,19 @@
 #' @aliases dim.edsurvey.data.frame.list
 #' @export
 dim.edsurvey.data.frame <- function(x) {
-  
   testVars <- NULL
   excludeVars <- NULL
-  
-  for(di in x$dataList){
-    if(di$isDimLevel){
+
+  for (di in x$dataList) {
+    if (di$isDimLevel) {
       testVars <- names(di$lafObject)
-    }else{
+    } else {
       excludeVars <- c(excludeVars, names(di$lafObject))
     }
   }
-  
-  nrow <- length(suppressWarnings(getData(x, testVars[!testVars %in% excludeVars][1], drop=TRUE, omittedLevels = FALSE, defaultConditions = FALSE)))
-  
+
+  nrow <- length(suppressWarnings(getData(x, testVars[!testVars %in% excludeVars][1], drop = TRUE, dropOmittedLevels = FALSE, defaultConditions = FALSE)))
+
   # every column must have a name
   ncol <- length(colnames(x))
   return(c(nrow, ncol))
@@ -42,13 +41,13 @@ dim.edsurvey.data.frame <- function(x) {
 #' @export
 dim.edsurvey.data.frame.list <- function(x) {
   res <- sapply(x$data, function(li) {
-    if(is.null(li)) {
-     c(NA,NA) 
-    } else { 
+    if (is.null(li)) {
+      c(NA, NA)
+    } else {
       dim(li)
     }
   })
-  return(list(nrow=res[1,], ncol=res[2,]))
+  return(list(nrow = res[1, ], ncol = res[2, ]))
 }
 
 # this method used internally to get the number of rows on the original data
@@ -65,13 +64,13 @@ dimnames.edsurvey.data.frame <- function(x) {
   nameVals <- colnames(x$cache)
   # these two are not intended to be shown
   nameVals <- nameVals[!nameVals %in% c("DEFAULT", "zzz_Filler")]
-  for(di in x$dataList){
-    if(!is.null(di$lafObject)){
+  for (di in x$dataList) {
+    if (!is.null(di$lafObject)) {
       nameVals <- c(nameVals, names(di$lafObject))
     }
   }
-  
-  return(list(NA,unique(nameVals)))
+
+  return(list(NA, unique(nameVals)))
 }
 
 #' @author Trang Nguyen
