@@ -1,7 +1,7 @@
 \dontrun{
 swe <- readTIMSSAdv("~/TIMSSAdv/2015",
                     countries = c("swe"), subject = "math")
-gg <- getData(swe, c("itsex", "totwgt", "malg"))
+gg <- getData(data=swe, varnames=c("itsex", "totwgt", "malg"))
 head(gg)
-edsurveyTable(malg ~ itsex, swe)
+edsurveyTable(formula=malg ~ itsex, swe)
 }
